pub struct Trace {
pub flags: BlockFlags,
pub block_offset: u32,
pub used_bitfield: u8,
pub prefetched_bitfield: u8,
}Fields
flags: BlockFlagsFlags for loading blocks: executable, resource, non-prefetchable or force prefetch.
block_offset: u32Memory block offset
used_bitfield: u8Stores whether the block was used in each of the last eight runs (1 bit each)
prefetched_bitfield: u8Stores whether the block was prefetched in each of the last eight runs (1 bit each)